@@ -1,6 +1,52 @@
 .__global__ <-
 c("d.units", "d.periodic", "d.prefix", "day.name", "day.abb", 
 "wdConst", "hblue", "hred", "hgreen")
+.CaptOut <-
+function(..., file = NULL, append = FALSE, width=150) {
+  
+  opt <- options(width=width)
+  
+  args <- substitute(list(...))[-1L]
+  rval <- NULL
+  closeit <- TRUE
+  if (is.null(file)) 
+    file <- textConnection("rval", "w", local = TRUE)
+  else if (is.character(file)) 
+    file <- file(file, if (append) 
+      "a"
+      else "w")
+  else if (inherits(file, "connection")) {
+    if (!isOpen(file)) 
+      open(file, if (append) 
+        "a"
+        else "w")
+    else closeit <- FALSE
+  }
+  else stop("'file' must be NULL, a character string or a connection")
+  sink(file)
+  on.exit({
+    sink()
+    if (closeit) close(file)
+    options(opt)
+  })
+  pf <- parent.frame()
+  evalVis <- function(expr) withVisible(eval(expr, pf))
+  for (i in seq_along(args)) {
+    expr <- args[[i]]
+    tmp <- switch(mode(expr), expression = lapply(expr, evalVis), 
+                  call = , name = list(evalVis(expr)), stop("bad argument"))
+    for (item in tmp) if (item$visible) 
+      print(item$value)
+  }
+  on.exit(options(opt))
+  sink()
+  if (closeit) 
+    close(file)
+  if (is.null(rval)) 
+    invisible(NULL)
+  else rval
+  
+}
 .DoCount <-
 function(y, x, wts) {
 
@@ -971,131 +1017,132 @@ structure(list(NA_real_, NA_real_, k3 = c(0.166666666666667,
 "k6", "k7", "k8", "k9", "k10", "k11", "k12", "k13", "k14", "k15"
 ))
 .Random.seed <-
-c(403L, 10L, -236118234L, 1465507905L, 843796947L, 1455143810L, 
-871436212L, -817428681L, -1249190355L, -579596476L, 1914702954L, 
-612726485L, -1230970769L, 241131894L, -1384158560L, 611604323L, 
--1442415615L, -1492277392L, -886771954L, -1386608263L, -1127596789L, 
-527484474L, -1518461636L, 2028868223L, 2058000853L, 1171412972L, 
--612701886L, 211515037L, -1898814697L, -116542850L, 952549944L, 
--1166502629L, 591356537L, -1806131512L, -550545674L, -1152450767L, 
-821229411L, -1928696526L, -1526624636L, 203647687L, 963611037L, 
--1714610924L, 2131325882L, -165669371L, -1131030561L, 1405824614L, 
-1402468848L, 50976531L, -704046927L, 2056014688L, 1618196734L, 
--2040141687L, -1876985925L, -1588792950L, -963485588L, 2687471L, 
--1833362907L, -1187107108L, 993789106L, 2140145581L, 1535458151L, 
-137042062L, 1853543784L, -1251736213L, -545331447L, -578479720L, 
--1283882810L, -847470047L, -2128926029L, -560408542L, -943103468L, 
--1720686953L, 1375795341L, -48685660L, -1712496758L, 1996491765L, 
-547283535L, 115070294L, -1800433664L, 889205059L, -613876511L, 
--1008085424L, 94792366L, 851291737L, -747571605L, 221985754L, 
--432386916L, 1073940127L, -1779577611L, 1069378956L, 1185298530L, 
-1467635773L, 821600951L, 1664051550L, -574246760L, -232801285L, 
--644077159L, 1974753832L, 189332182L, -2143899823L, -897125885L, 
--1979742830L, -925154524L, 1775637991L, 1754456637L, 1610243252L, 
--2030462182L, -177557403L, -1279362817L, -79660666L, 383979280L, 
--1380836429L, 1979881553L, 1172540416L, -862761762L, 520068905L, 
-1440760539L, -324503062L, 394510732L, 1090119375L, 1604844165L, 
--1895722692L, 363281426L, 1355813645L, 863625287L, 281088558L, 
-88529800L, -1006799221L, 1451755625L, -1918135240L, 1592939750L, 
--172925823L, -1487176685L, -535258174L, -581655436L, 679549559L, 
--195493011L, 169169924L, 2014301994L, -794801003L, 395610927L, 
-971233846L, -1424220576L, 774159523L, 1140561857L, 1716921264L, 
-2105427662L, 1841108025L, -1082365365L, 2145402874L, 7854844L, 
--1637322945L, -1503002603L, -1124658388L, 608188418L, 1031865053L, 
-1514891735L, -694377282L, 60104440L, -1721611045L, 1436700473L, 
--1654003064L, -1253257674L, -990855567L, -150659933L, 549197298L, 
--1932520124L, 702797319L, 174707677L, -1634485036L, 1312973818L, 
--989293755L, -1417246817L, -1425240794L, 2118833584L, 987418195L, 
--1846539919L, 1964597408L, 201535550L, 1478121289L, 1503149563L, 
--1249254966L, 1399656236L, 506359599L, -1154851355L, 194896028L, 
--535477006L, -1879917203L, 1901431463L, -1418976050L, 803998248L, 
-1034279467L, 389066825L, -433163944L, -1601755130L, 297294305L, 
-1915986803L, -408963102L, -583065772L, 791335511L, -151010739L, 
-423175652L, -492634166L, -2025143755L, 1653393551L, -1541457514L, 
--2116025024L, 257349635L, -939275743L, 581111056L, 46695150L, 
--464527719L, -1235460309L, -2114479590L, 1218365660L, 907150559L, 
-1985544885L, -2142399412L, 1765009570L, 2132191229L, -144059145L, 
--1364803042L, -400458536L, 2064007227L, 370985433L, 1160032104L, 
-888677014L, 1283238929L, 1681063363L, -1100335540L, -1148068996L, 
-744903986L, -1214357904L, 759106372L, 1885705176L, -1571868806L, 
-208015920L, 939150268L, -255155628L, -805155774L, -931596128L, 
--1415728452L, -1648321072L, -376146078L, 804205288L, -1433463604L, 
-437374460L, -1852999182L, -470575488L, -290241036L, -1738743160L, 
-354776890L, -930504880L, -1490215828L, -1434227308L, -1975804846L, 
-1889135072L, 1209726156L, 1701200032L, 1262922114L, 697252072L, 
--1361005844L, 879670588L, 2123562098L, 982213744L, -648696796L, 
--1561722824L, 553671450L, 1359404240L, 676465468L, 1053620116L, 
--2116989054L, -289135168L, 1773679164L, -882185840L, -508483038L, 
--2011165432L, 707517068L, 928368412L, -1532518254L, 173941120L, 
--1873968620L, -1956527320L, -2017065414L, 1734379984L, 767972716L, 
--1998494796L, 1738984466L, -1561284128L, 1014088652L, 902283488L, 
--404203486L, 1931144488L, -2072807924L, 225309500L, -890764302L, 
-1400979184L, -829982140L, 1131241048L, 171422522L, 449266160L, 
--1320722756L, -580907756L, 315064002L, -1533943712L, -833353860L, 
--1783817264L, -1210708702L, 571532968L, 413879180L, -454992708L, 
--2090830030L, -1592683968L, -958003020L, -1660212664L, -1919144518L, 
--633032176L, 971390700L, -480600748L, 1575986450L, -1268885088L, 
--550797620L, 589198944L, -240753726L, -1703689432L, 430742444L, 
-40984380L, -269177486L, 974593840L, -352541404L, -1233155272L, 
-1157283546L, -3935344L, -1408730372L, 577934228L, -564936638L, 
-808665344L, 1305556028L, 2078029136L, 527487138L, -1681851064L, 
--186287348L, -1465552164L, 624558418L, 1109377152L, 1991097428L, 
--175641624L, 1058260218L, 548688L, 619851564L, -276812428L, 1907806098L, 
--1125794720L, 1966441868L, 1557773152L, 1740137954L, 306308008L, 
-301625548L, 2067594236L, -2009935438L, 2046959088L, -1004982332L, 
--1888919208L, -468318854L, -1951141968L, 1565578684L, 1438585940L, 
-1234724802L, -978999264L, -912021316L, -242837936L, 1499836386L, 
--286185368L, 1816256588L, -2057612036L, -237078542L, -1209680640L, 
-1161123188L, 1618872328L, -621268038L, 1151198672L, 1529171948L, 
--2016432748L, 873667026L, 1158865248L, 1041357644L, 125471008L, 
-652699522L, 1045382888L, -1100025620L, 2072995900L, -1285550222L, 
--2089296272L, -1141171164L, -692385992L, 794727578L, 615686864L, 
-996133052L, 1773835924L, -1656373630L, 257689792L, 836427580L, 
--1296043888L, -1023494622L, -1379353592L, 1041653004L, -1611195236L, 
-1064055314L, 178897792L, 1676244500L, -1974323672L, -1686266566L, 
--1988454960L, -242716564L, 1574380852L, 1475035794L, 1296209760L, 
-753078092L, -1625550880L, 594856866L, 1848372136L, -598107764L, 
--1236089668L, 1992503666L, 1083764976L, -418168764L, -1018589864L, 
--2070748614L, -860774544L, -1342477252L, 1333168916L, 1351636418L, 
-1327781600L, -194038916L, -906685744L, -1014229854L, -1800443864L, 
-2037057804L, 649335740L, -889174734L, 1926365632L, 1962865204L, 
--1712437304L, 269083834L, 700504464L, 1327210988L, -984105388L, 
--1637356398L, 1712012064L, -404790836L, -1325023776L, 166112962L, 
--436735960L, 454123180L, -1594527556L, 866833906L, 544287406L, 
--315861060L, -1748922323L, -761081897L, -1027955168L, 1197164414L, 
-2038769995L, 474155853L, -946914950L, -295461960L, 376086881L, 
--359305965L, 1813574964L, -111763646L, 474988375L, 881397409L, 
-766599014L, 1649416548L, 832519317L, -314952257L, 1337661784L, 
--1989257354L, -1023777405L, -1327800379L, 814048482L, -2084740784L, 
-690552953L, 2024473515L, -1042011876L, 1619582538L, -278971841L, 
-1097395849L, 704813726L, 1126442828L, -989020387L, 712703655L, 
-829552080L, -1290572434L, -2070478821L, 133067133L, -410294422L, 
-872866312L, 1683080881L, -214449885L, -211791324L, -1292748590L, 
-1274573095L, -1732347023L, -499029578L, 515932500L, 1523449829L, 
-1247009263L, 1887019304L, -141969018L, 299738547L, 2063132949L, 
--1535468686L, -1050953792L, -1519093719L, -968182629L, -2050895508L, 
-1130223994L, 414038703L, 410087865L, 97221582L, 1901232924L, 
-1954470541L, 1029243639L, 766813696L, 299368542L, -600335573L, 
-1219762221L, 1401143450L, -222444456L, -355417151L, -2080428941L, 
-1467340180L, -1996821470L, 2386743L, 1350577665L, -513163514L, 
--1356344508L, 153101941L, -1485277217L, 1996114744L, -193020650L, 
-396583203L, -1112560923L, -1600986366L, -1053103760L, -442384103L, 
--419045109L, 660423164L, 747215402L, 928983647L, -841172503L, 
--1691995394L, 2121890540L, 347982397L, 1680566791L, 241221104L, 
--220123762L, -1245006917L, -351081059L, 1560834890L, 463652712L, 
-1920706897L, 538511939L, -165007548L, 866337778L, -71149113L, 
--955658351L, 442922774L, -1192967308L, -260408827L, 372681295L, 
--977074616L, -662575130L, -1902565101L, 1818146421L, -1452405678L, 
--1248147808L, -1713183863L, -352206917L, -711393268L, 1749921178L, 
--938750705L, 1048482649L, -796365330L, 942426236L, 1372019949L, 
-510155671L, 1208288352L, -947378626L, 695398155L, -1111616115L, 
--42262854L, 523414776L, -1910945119L, -883439021L, 2032186740L, 
--130163966L, -615445609L, -568156831L, -1148502618L, -618004572L, 
-923298389L, -1233306881L, -768196712L, 1404817590L, 1507767619L, 
-24786053L, -1816851166L, -1978034672L, -603130439L, 420218475L, 
--1700988580L, 1480593546L, -359958401L, 1407728073L, 684735070L, 
-1749709068L, 1512318173L, -1344638489L, 711256592L, -2146285778L, 
--1953936421L, 1887915197L, -1192292822L, 290199815L)
+c(403L, 10L, 768819836L, 63960767L, 1118404501L, -1779484756L, 
+683165058L, 1992846173L, -1749227945L, 306328894L, -1730796168L, 
+-391326117L, 349413817L, -1603804152L, -2001068362L, -970502671L, 
+1638433827L, 1244372082L, -1224753468L, -964372345L, 1985756253L, 
+-1656774060L, 1913878650L, -122168379L, 139521311L, -385467226L, 
+878669360L, -1704225581L, -554460431L, 507267616L, 1393896638L, 
+1803729097L, -1919948165L, 1433395274L, 1351839916L, 630876079L, 
+938496869L, -2062137060L, -2092125838L, 2074677741L, -1114507737L, 
+294843982L, -379675992L, 1635973291L, 1221919177L, 3100120L, 
+105405574L, -747830943L, 1993360627L, -1661301918L, -596130348L, 
+-486944553L, -533642547L, -2011667868L, 714422346L, -1133032011L, 
+6459663L, 1952247318L, 1707075776L, -342499709L, -1452336479L, 
+-789787504L, -410515602L, -188710631L, -1495416405L, 567541658L, 
+842452828L, 1015119455L, 1648881205L, 1141362124L, 253611298L, 
+-1998686339L, 2064649335L, 1405784478L, 1768171608L, -1398581829L, 
+-1500390567L, -1125267224L, 1628326166L, 219519633L, -1752246461L, 
+-2039651758L, -89807644L, 1049956135L, 513862525L, 309579380L, 
+-193933222L, 1748437157L, 1812781759L, -1506041530L, -1698441264L, 
+956367347L, 1838099729L, 1356122432L, -725247714L, -1731699223L, 
+-1132736741L, 1258920234L, 1017246284L, -428601841L, 1235493189L, 
+-201880836L, 1786896722L, 717801165L, 811040391L, 1201359214L, 
+-1435942072L, -360319157L, -1404158295L, -762616840L, 377649958L, 
+887450689L, 534207955L, 1734446978L, -2135882828L, -1823720649L, 
+1154472493L, 1858902852L, -1933512598L, -1923200299L, -826108817L, 
+-1673851530L, -1233217888L, 1867191139L, -709920767L, -1726839952L, 
+1097689870L, -751401607L, -795156213L, -1833590214L, 1855322428L, 
+604362367L, 942210517L, -1355631636L, -569957054L, 773290653L, 
+-1629317353L, 390903422L, -1834600904L, -1028206309L, 1800238713L, 
+-1716227384L, -1747844362L, -1245312207L, 1034369891L, 1602785586L, 
+-2064010620L, 202759879L, -1562204771L, 640266516L, -127803462L, 
+-1314973179L, -1360499745L, 23151206L, 1919434224L, 759630611L, 
+-1311009615L, 536078176L, -895081218L, -989043575L, 1672496059L, 
+-280859254L, 621800556L, 295355887L, -2065818075L, -899941668L, 
+-595447630L, -199621715L, 1868986215L, -736115570L, 410829160L, 
+1509409131L, 77886217L, -39328360L, 175297734L, 2109353505L, 
+519278259L, -1010338782L, 1013837332L, -2019188073L, -456655731L, 
+-1253068380L, -387736694L, 896333813L, 1533032015L, 2074857814L, 
+-1917699072L, 1782281539L, -1944291103L, 1361613392L, -1202327890L, 
+-1047446951L, 1209844331L, -2088294438L, 1246873756L, -92484961L, 
+1227221237L, 1818734988L, -1888011166L, 652102717L, -164856137L, 
+-1136550562L, -893320040L, 543649787L, -139086439L, 1543423528L, 
+-6848810L, -1980621999L, 114245123L, -1932549742L, 535691044L, 
+-1893928473L, -1155277251L, 1325205684L, 1985896218L, 1848415333L, 
+-658514689L, 630410630L, 1654686480L, -1233168461L, 869612625L, 
+685826048L, -880242466L, 1389964073L, -1277094181L, -1847720470L, 
+-1581232756L, 1960714959L, 445357701L, 268551284L, -1565722104L, 
+1637274042L, 1759664592L, 1797084140L, -1945872492L, -1138019118L, 
+-1148989344L, -121329332L, 495488800L, 1168855682L, 1811976680L, 
+-729893908L, 747216444L, 335495794L, -1735407760L, -72408796L, 
+1040322104L, 1992777114L, 102528464L, 709857724L, 1169369748L, 
+920901250L, 2065971648L, 645406524L, 2017199760L, -595676382L, 
+-1731604984L, 1031689996L, -1350164580L, -85686254L, -83790976L, 
+2134171412L, -1602299608L, 1139419194L, 1355376592L, -628579732L, 
+-927435724L, -1508467566L, -569711264L, -414805684L, -179678752L, 
+1432389538L, -776147032L, 1352154252L, 1940052924L, 2042937458L, 
+1734054896L, -1681723324L, 781538392L, -1945683910L, 935776368L, 
+281356860L, 1895512852L, 1065832130L, -630522144L, 1859007612L, 
+2105680080L, -386624606L, 828416552L, -2020549364L, 2090331068L, 
+-997626574L, -806243136L, 629177908L, -801139000L, 2140081850L, 
+-253925232L, 2127276780L, 571626068L, 2098206354L, -526775520L, 
+608586700L, 1384621280L, -103191870L, 171139112L, 616833964L, 
+-2128493892L, -721187342L, 1276661296L, -1544812636L, -954448456L, 
+1118553946L, -114546544L, -1577303172L, -1995474156L, 1349206338L, 
+47436544L, -1548421188L, -1853897904L, 2141826338L, -195672504L, 
+-1743845364L, 1499920476L, -33832494L, -787209728L, 1774877012L, 
+389686504L, 959642874L, 1160675024L, 445248812L, -943671052L, 
+240819602L, -1775759008L, -1737175028L, 115353312L, -609203614L, 
+1023346344L, 1306310220L, -449903748L, 1452873010L, -936511888L, 
+-1127683260L, 220672984L, 2007674746L, -212907472L, -704734276L, 
+1511703124L, -997792702L, 664707232L, -1705137476L, -400347696L, 
+-1655343262L, 846424808L, 272757964L, 782564860L, -1528600078L, 
+838682240L, 1353172468L, -1525304696L, 452497210L, 1602957136L, 
+-796771220L, -1961511532L, -1034005422L, -770450976L, -1789678388L, 
+1757485216L, 82819458L, 2035779816L, -924087572L, 1507587388L, 
+407139442L, -1214575504L, -448023516L, -1718091720L, -1720454374L, 
+-1804655408L, -1292876996L, 277122964L, -346015870L, -279552576L, 
+453644860L, -74049136L, -1858493918L, -830112504L, -1790106996L, 
+1492985628L, 1132288146L, 2139228544L, 2021206548L, -1371835608L, 
+-736117190L, 857637328L, -1040497300L, 1443830708L, 1853803538L, 
+1356823008L, 1475001292L, -1700661024L, 1889906722L, 1540500776L, 
+1702120972L, -1136481476L, 2116805618L, 1657999088L, 321917508L, 
+785256024L, -954387654L, 1312596464L, -1403928900L, -542782188L, 
+1264539330L, -1181280160L, -525482116L, -823235632L, -1229550302L, 
+-1761306968L, -102487156L, 1072045244L, 974784306L, 1984240192L, 
+1056235700L, 268913224L, 898862522L, -1276370416L, -1939466516L, 
+-2120174252L, -1509837550L, 920738208L, -181586228L, -1737929120L, 
+-1353516094L, -59167960L, -2115667028L, 1106591548L, 242654578L, 
+413306672L, 503592228L, 661422904L, -1162985766L, -1004901488L, 
+244472572L, -357088364L, -1966432190L, -1061388032L, 199760956L, 
+1897878864L, 787837090L, -229595832L, -559658228L, -1674171684L, 
+-363622062L, 1689766016L, -622252972L, -165297176L, 1416715514L, 
+-198949352L, -1714107082L, -1982987325L, 1575332357L, -1602162270L, 
+-1981377136L, 424678713L, -476274197L, 2058412764L, 1253000970L, 
+-997422593L, 504520777L, 208120286L, 1195962764L, -2034913955L, 
+-679916185L, 891367056L, 269037742L, -2146741925L, 2083177789L, 
+-1493985366L, 1081815112L, -895629199L, 1311376867L, -1897512732L, 
+926174226L, 2056800231L, -1751797839L, -1142996490L, -236360684L, 
+407458597L, -287587281L, -182741528L, -123452730L, -972723341L, 
+1887065045L, 1051327410L, -857842304L, 549430633L, -1887647269L, 
+384594220L, -1382436038L, -1956409873L, -1496532871L, -122920178L, 
+116537052L, -604535475L, 1463507127L, 1909858880L, 789486366L, 
+1469972971L, 1279798637L, -1196051494L, 275862936L, -1551082495L, 
+-819315277L, -1512299308L, 74592738L, 1454599287L, 569438657L, 
+1965517638L, 2104800900L, 830775349L, -900468705L, -1178093704L, 
+-748958122L, -1895873821L, -1159273307L, -1547571902L, 913324848L, 
+-1617633447L, -1439861557L, -1693080260L, 732295530L, 884038559L, 
+862893609L, -1211107138L, -1675263572L, 2062204669L, 1711336007L, 
+1617430832L, -1581911474L, -1751729541L, -374978083L, 1610162186L, 
+-998973144L, -462913647L, 877670787L, 102518404L, -1477448526L, 
+-714617849L, -729016239L, 1119496150L, 1738008244L, 1618802373L, 
+-1450620913L, -826443640L, 779831718L, -1190842029L, 1803715253L, 
+-432179182L, -2096940576L, -396211127L, -108561797L, 41435980L, 
+90113754L, 374422223L, 580414105L, -1856690514L, -1301777476L, 
+-1170297811L, -1572346921L, 175344160L, 1799867262L, -1907387061L, 
+-1971611827L, 1357356410L, 211640248L, 369370465L, 1346189587L, 
+1976971572L, -742945982L, 1833765719L, 1001777825L, -1584911514L, 
+1268794724L, 659837077L, 518349247L, -566504104L, -1417122954L, 
+-1853404797L, 1318628293L, 662384866L, -782187184L, 215983225L, 
+-2143668309L, 1453571356L, 848779850L, -1501266369L, 1783534217L, 
+2050045598L, 1465746252L, -311672035L, -1288039769L, 2116983248L, 
+-2039115410L, 848296987L, -1342876291L, 1877418858L, 1797191176L, 
+1041550001L, -1304578781L, -249387484L, -297833262L, 551038247L, 
+-1805269135L, 631498166L, 1635192148L, -664507419L, 819754479L, 
+-1239687896L, -1012994682L, 1481370035L, 157656341L, 1657571186L, 
+1181426624L, -1729797079L, 2032955547L, -159982228L, -867673634L
+)
 .txtline <-
 function(txt, width, space="", ind="") {
   paste(
@@ -1128,18 +1175,18 @@ function(wrd, main="Bericht" ){
   wrd[["Selection"]]$WholeStory()
   # 15.1.2012 auskommentiert: WrdSetFont(wrd=wrd)
   
-  # Idee: berschrift definieren (geht aber nicht!)
-  #wrd[["ActiveDocument"]][["Styles"]]$Item("berschrift 2")[["Font"]][["Name"]] <- "Consolas"
-  #wrd[["ActiveDocument"]][["Styles"]]$Item("berschrift 2")[["Font"]][["Size"]] <- 10
-  #wrd[["ActiveDocument"]][["Styles"]]$Item("berschrift 2")[["Font"]][["Bold"]] <- TRUE
+  # Idee: ueberschrift definieren (geht aber nicht!)
+  #wrd[["ActiveDocument"]][["Styles"]]$Item("ueberschrift 2")[["Font"]][["Name"]] <- "Consolas"
+  #wrd[["ActiveDocument"]][["Styles"]]$Item("ueberschrift 2")[["Font"]][["Size"]] <- 10
+  #wrd[["ActiveDocument"]][["Styles"]]$Item("ueberschrift 2")[["Font"]][["Bold"]] <- TRUE
   
-  #wrd[["ActiveDocument"]][["Styles"]]$Item("berschrift 2")[["ParagraphFormat"]]["Borders"]]$Item(wdBorderTop)[["LineStyle"]] <- wdConst$wdLineStyleSingle
+  #wrd[["ActiveDocument"]][["Styles"]]$Item("ueberschrift 2")[["ParagraphFormat"]]["Borders"]]$Item(wdBorderTop)[["LineStyle"]] <- wdConst$wdLineStyleSingle
   
   WrdCaption( main, wrd=wrd)
   wrd[["Selection"]]$TypeText(gettextf("%s/%s\n",format(Sys.time(), "%d.%m.%Y"), Sys.getenv("username")))
   wrd[["Selection"]]$InsertBreak( wdConst$wdPageBreak)
   
-  # Inhaltsverzeichnis einfgen ***************
+  # Inhaltsverzeichnis einfuegen ***************
   wrd[["ActiveDocument"]][["TablesOfContents"]]$Add( wrd[["Selection"]][["Range"]] )
   # Original VB-Code:
   # With ActiveDocument
