@@ -36,7 +36,7 @@ function(x, wrd, main = deparse(substitute(x)), ...) {
   
   if(!is.null(main)) WrdCaption(x=main, wrd=wrd)
   
-  txt <- capture.output(Desc(x, ...))[-(1:2)]
+  txt <- .CaptOut(Desc(x, ...))[-(1:2)]
   
   # insert table
   if(inherits(x, "Date")) {
@@ -63,7 +63,14 @@ function(x, wrd, main = deparse(substitute(x)), ...) {
   
   # corr 8.11.2014: not sure if we need the dots here, anyway they can produce errors
   # PlotDesc(x, main="", ..., wrd=wrd)
-  PlotDesc(x, main="", wrd=wrd)
+  if(any(class(x)=="table")){
+    horiz <- InDots(..., arg="horiz", default = TRUE)
+    PlotDesc(x, main="", wrd=wrd, horiz=horiz)  # 2.2.2015: table might need the horiz argument, that's clearly a hack...
+    # ...  rises a warning for disregarding other arguments, as verbose for example
+    #  ******* KEEP AN EYE ON ME *****************    
+  } else {
+    PlotDesc(x, main="", wrd=wrd)
+  }
 
   wrd[["Selection"]]$EndOf( wdConst$wdTable )
   # get out of tablerange
