@@ -1,7 +1,7 @@
 LogitInv <-
-function(x, min=0, max=1)
-  {
+function(x, min=0, max=1) {
+  
     p <- exp(x)/(1+exp(x))
     p <- ifelse( is.na(p) & !is.na(x), 1, p ) # fix problems with +Inf
     p * (max-min) + min
-  }
+}
